/*
 *
 * EMSans6x8
 *
 *
 * File Name           : EMSans6x8.h
 * Date Created        : 23 November 2019
 * Date Updated        : 23 November 2019
 * Font width          : 6
 * Font height         : 8
 * Font first char     : 32
 * Font last char      : 127
 * Font used chars     : 94
 *
 * The font data are defined as
 *
 * struct _FONT_ {
 *     uint16_t   font_Size_in_Bytes_over_all_included_Size_it_self;
 *     uint8_t    font_Width_in_Pixel_for_fixed_drawing;
 *     uint8_t    font_Height_in_Pixel_for_all_characters;
 *     unit8_t    font_First_Char;
 *     uint8_t    font_Char_Count;
 *
 *     uint8_t    font_Char_Widths[font_Last_Char - font_First_Char +1];
 *                  // for each character the separate width in pixels,
 *                  // characters < 128 have an implicit virtual right empty row
 *
 *     uint8_t    font_data[];
 *                  // bit field of all characters
 */

#include <inttypes.h>
#ifdef __AVR__
#include <avr/pgmspace.h>
#elif defined (ESP8266)
#include <pgmspace.h>
#else
#define PROGMEM
#endif

#ifndef EMSANS6x8_H
#define EMSANS6x8_H

#define EMSANS6x8_WIDTH 6
#define EMSANS6x8_HEIGHT 8

/*
 * added to allow fontname to match header file name. 
 * as well as keep the old name for backward compability
 */

#define EMSans6x8 EMSans6x8

const static uint8_t EMSans6x8[] PROGMEM = {
    0x05, 0x07, // size // size of zero indicates fixed width font, actual length is width * height
    0x06, // width
    0x08, // height
    0x20, // first char
    0x60, // char count
    
0x02,0x06,0x06,0x13,0x0A,0x0A,0x03,0x01,0x06,0x06, //	!	"	#	$	%	&	'	(	)
0x03,0x06,0x04,0x06,0x04,0x06,0x06,0x06,0x06,0x06, //*	+   	,	-	.	/	0	1	2	3
0x06,0x06,0x06,0x06,0x06,0x06,0x04,0x06,0x06,0x06, //4	5	6	7	8	9	:	;	<	=
0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06, //>	?	@	A	B	C	D	E	F	G
0x06,0x02,0x05,0x06,0x05,0x07,0x06,0x06,0x06,0x06, //H	I	J	K	L	M	N	O	P	Q
0x06,0x06,0x06,0x06,0x06,0x07,0x06,0x06,0x06,0x06, //R	S	T	U	V	W	X	Y	Z	[
0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06, //\	]	^	_	`	a	b	c	d	e
0x05,0x06,0x06,0x02,0x03,0x06,0x02,0x07,0x06,0x06, //f	g	h	i	j	k	l	m	n	o
0x06,0x06,0x05,0x06,0x05,0x06,0x06,0x07,0x06,0x06, //p	q	r	s	t	u	v	w	x	y
0x06,0x06,0x06,0x06,0x06,0x06,
    
	// font data
	0x00, 0x00,// (space)
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// !
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// "
	0x02, 0x7f, 0x7e, 0x60, 0x78, 0x7c, 0x7c, 0x7e, 0x4e, 0x47, 0x4e, 0x7e, 0x7c, 0x7c, 0x78, 0x60, 0x7e, 0x7f, 0x02,// #
	0x3e, 0x7f, 0x7f, 0x7f, 0x63, 0x77, 0x7f, 0x7f, 0x7f, 0x3e,// $
	0x08, 0x1c, 0x14, 0x36, 0x22, 0x22, 0x36, 0x14, 0x1c, 0x08,// %
	0x73, 0x54, 0x33, // &
	//0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// &
	0x06,// '
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// (
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// )
	0x07, 0x05, 0x07,// *
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// +
	0x00, 0x60, 0xe0, 0x00,// ,
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// -
	0x00, 0x60, 0x60, 0x00, // .
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// /
	0x3e, 0x7f, 0x63, 0x63, 0x7f, 0x3e,// 0
	0x00, 0x62, 0x7f, 0x7f, 0x60, 0x00,// 1
	0x73, 0x7b, 0x6b, 0x6b, 0x6f, 0x6e,// 2
	0x63, 0x63, 0x6b, 0x6b, 0x7f, 0x36,// 3
	0x0f, 0x1f, 0x18, 0x18, 0x7f, 0x7f,// 4
	0x6f, 0x6f, 0x6b, 0x6b, 0x7b, 0x33,// 5
	0x3e, 0x7f, 0x6b, 0x6b, 0x7b, 0x32,// 6
	0x03, 0x03, 0x03, 0x73, 0x7f, 0x0f,// 7
	0x3e, 0x7f, 0x6b, 0x6b, 0x7f, 0x3e,// 8
	0x26, 0x6f, 0x6b, 0x6b, 0x7f, 0x3e,// 9
	0x00, 0x16, 0x34, 0x00,// :
	0x00, 0x36, 0x36, 0x76, 0x74, 0x00,// ;
	0x1c, 0x3e, 0x36, 0x36, 0x36, 0x34,// <
	0x16, 0x36, 0x36, 0x36, 0x36, 0x34,// =
	0x16, 0x36, 0x36, 0x36, 0x3e, 0x1c,// >
	0x03, 0x07, 0x03, 0x5b, 0x5f, 0x0e,// ?
	0x7f, 0x41, 0x5d, 0x55, 0x5d, 0x7d,// @
	0x7e, 0x7f, 0x13, 0x13, 0x7f, 0x7e,// A
	0x7f, 0x7f, 0x6b, 0x6b, 0x7f, 0x36,// B
	0x3e, 0x7f, 0x63, 0x63, 0x63, 0x63,// C
	0x7f, 0x7f, 0x63, 0x63, 0x7f, 0x3e,// D
	0x7f, 0x7f, 0x6b, 0x6b, 0x6b, 0x63,// E
	0x7f, 0x7f, 0x13, 0x13, 0x13, 0x03,// F
	0x3e, 0x7f, 0x63, 0x6b, 0x7b, 0x7b,// G
	0x7f, 0x7f, 0x08, 0x08, 0x7f, 0x7f,// H
	0x7f, 0x7f, // I
	0x63, 0x63, 0x63, 0x7f, 0x3f,// J
	0x7f, 0x7f, 0x08, 0x1c, 0x77, 0x63,// K
	0x7f, 0x7f, 0x60, 0x60, 0x60,// L
	0x7f, 0x7f, 0x06, 0x0c, 0x06, 0x7f, 0x7f,// M
	0x7f, 0x7f, 0x02, 0x04, 0x7f, 0x7f,// N
	0x3e, 0x7f, 0x63, 0x63, 0x7f, 0x3e,// O
	0x7f, 0x7f, 0x13, 0x13, 0x1f, 0x0e,// P
	0x3e, 0x7f, 0x63, 0x73, 0x3f, 0x5e,// Q
	0x7f, 0x7f, 0x13, 0x13, 0x7f, 0x6e,// R
	0x66, 0x6f, 0x6b, 0x6b, 0x7b, 0x33,// S
	0x03, 0x03, 0x7f, 0x7f, 0x03, 0x03,// T
	0x3f, 0x7f, 0x60, 0x60, 0x7f, 0x3f,// U
	0x1f, 0x3f, 0x70, 0x60, 0x3f, 0x1f,// V
	0x7f, 0x7f, 0x20, 0x10, 0x20, 0x7f, 0x7f,// W
	0x63, 0x77, 0x08, 0x08, 0x77, 0x63,// X
	0x07, 0x0f, 0x78, 0x78, 0x0f, 0x07,// Y
	0x73, 0x73, 0x6b, 0x6b, 0x67, 0x67,// Z
	0x1c, 0x3c, 0x3c, 0x3c, 0x3c, 0x38,// [
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// "\"
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// ]
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// ^
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// _
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// `
	0x3c, 0x7e, 0x66, 0x26, 0x7e, 0x7c,// a
	0x7f, 0x7f, 0x66, 0x66, 0x7e, 0x3c,// b
	0x3c, 0x7e, 0x66, 0x66, 0x66, 0x24,// c
	0x3c, 0x7e, 0x66, 0x66, 0x7f, 0x7f,// d
	0x3c, 0x7e, 0x66, 0x76, 0x6e, 0x6c,// e
	0x7e, 0x7f, 0x13, 0x13, 0x03,// f
	0x9c, 0xbe, 0xb6, 0xb6, 0xfe, 0x7c,// g
	0x7f, 0x7f, 0x06, 0x06, 0x7e, 0x7c,// h
	0x7d, 0x7d, // i
	0x80, 0xfb, 0xfb, // j
	0x7f, 0x7f, 0x10, 0x38, 0x6e, 0x66,// k
	0x7f, 0x7f, // l
	0x7c, 0x7e, 0x06, 0x0c, 0x06, 0x7e, 0x7c,// m
	0x7c, 0x7e, 0x06, 0x06, 0x7e, 0x7c,// n
	0x3c, 0x7e, 0x66, 0x66, 0x7e, 0x3c,// o
	0xfc, 0xfe, 0x66, 0x66, 0x7e, 0x3c,// p
	0x3c, 0x7e, 0x66, 0x66, 0xfe, 0xfc,// q
	0x7c, 0x7e, 0x06, 0x06, 0x06,// r
	0x64, 0x6e, 0x6e, 0x76, 0x76, 0x26,// s
	0x02, 0x3f, 0x7f, 0x62, 0x60,// t
	0x3e, 0x7e, 0x60, 0x60, 0x7e, 0x3e,// u
	0x1e, 0x3e, 0x70, 0x60, 0x3e, 0x1e,// v
	0x3e, 0x7e, 0x60, 0x30, 0x60, 0x7e, 0x3e,// w
	0x66, 0x6e, 0x10, 0x10, 0x6e, 0x66,// x
	0x9e, 0xbe, 0xb0, 0xb0, 0xfe, 0x7e,// y
	0x66, 0x76, 0x76, 0x6e, 0x6e, 0x66,// z
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// {
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// |
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// }
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e,// ->
	0x3e, 0x3e, 0x26, 0x26, 0x7e, 0x7e // <-
    
};

#endif
